@@ -64,7 +64,7 @@ def test_read_cache_file_successful():
 
 
 def test_read_cache_does_not_exist(tmpdir):
-    cache = DependencyCache(cache_dir=str(tmpdir))
+    cache = DependencyCache(cache_dir=tmpdir)
     assert cache.cache == {}
 
 
@@ -72,20 +72,17 @@ def test_read_cache_does_not_exist(tmpdir):
     sys.platform == "win32", reason="os.fchmod() not available on Windows"
 )
 def test_read_cache_permission_error(tmpdir):
-    cache = DependencyCache(cache_dir=str(tmpdir))
+    cache = DependencyCache(cache_dir=tmpdir)
     with open(cache._cache_file, "w") as fp:
         os.fchmod(fp.fileno(), 0o000)
     with pytest.raises(IOError, match="Permission denied"):
-        cache.read_cache()
+        cache.cache
 
 
 def test_reverse_dependencies(from_line, tmpdir):
-    # Since this is a test, make a temporary directory. Converting to str from py.path.
-    tmp_dir_path = str(tmpdir)
-
     # Create a cache object. The keys are packages, and the values are lists
     # of packages on which the keys depend.
-    cache = DependencyCache(cache_dir=tmp_dir_path)
+    cache = DependencyCache(cache_dir=tmpdir)
     cache[from_line("top==1.2")] = ["middle>=0.3", "bottom>=5.1.2"]
     cache[from_line("top[xtra]==1.2")] = ["middle>=0.3", "bottom>=5.1.2", "bonus==0.4"]
     cache[from_line("middle==0.4")] = ["bottom<6"]
@@ -121,4 +118,4 @@ def test_reverse_dependencies(from_line, tmpdir):
     }
 
     # Clean up our temp directory
-    rmtree(tmp_dir_path)
+    rmtree(tmpdir)
